# eric7.Plugins.VcsPlugins.vcsMercurial.HgBookmarkDialog

Module implementing the bookmark dialog.

### Global Attributes

None

### Classes

HgBookmarkDialog | Class mplementing the bookmark dialog.

### Functions

None

## HgBookmarkDialog

Class mplementing the bookmark dialog.

### Derived from

QDialog, Ui_HgBookmarkDialog

### Class Attributes

DEFINE_MODE
MOVE_MODE

### Class Methods

None

### Methods

HgBookmarkDialog | Constructor
__updateBookmarksCombo | Private slot to update the bookmarks combo.
__updateOK | Private slot to update the OK button.
getData | Public method to retrieve the entered data.

### Static Methods

None

#### HgBookmarkDialog (Constructor)

HgBookmarkDialog(mode, tagsList, branchesList, bookmarksList, parent=None)

Constructor

mode (int)
  of the dialog
tagsList (list of str)
  list of tags
branchesList (list of str)
  list of branches
bookmarksList (list of str)
  list of bookmarks
parent (QWidget)
  parent widget

#### HgBookmarkDialog.__updateBookmarksCombo

__updateBookmarksCombo()

Private slot to update the bookmarks combo.

#### HgBookmarkDialog.__updateOK

__updateOK()

Private slot to update the OK button.

#### HgBookmarkDialog.getData

getData()

Public method to retrieve the entered data.

Return:
  tuple naming the revision and the bookmark name

Return Type:
  tuple of (str, str)

Up